==> jc-1.4.0.tar.gz: javax/xml/validation/TypeInfoProvider.h <==
// public abstract class javax.xml.validation.TypeInfoProvider

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf22387b95bb0cb1 javax_xml_validation_TypeInfoProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_validation_TypeInfoProvider_H_
#define _JC_javax_xml_validation_TypeInfoProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_TypeInfo$object;

// Typedefs
typedef struct _jc_javax_xml_validation_TypeInfoProvider$sub_refs	_jc_javax_xml_validation_TypeInfoProvider$sub_refs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs	_jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$refs	_jc_javax_xml_validation_TypeInfoProvider$refs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$nonrefs	_jc_javax_xml_validation_TypeInfoProvider$nonrefs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$object	_jc_javax_xml_validation_TypeInfoProvider$object;

typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vmethods	_jc_javax_xml_validation_TypeInfoProvider$vmethods;
typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vtable	_jc_javax_xml_validation_TypeInfoProvider$vtable;
typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vtype	_jc_javax_xml_validation_TypeInfoProvider$vtype;

// Constructors
extern void _jc_javax_xml_validation_TypeInfoProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_xml_validation_TypeInfoProvider$method$getAttributeTypeInfo$5fe17b3fb8096ff1(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);
extern struct _jc_object *_jc_javax_xml_validation_TypeInfoProvider$method$getElementTypeInfo$2ad99f5acfd4cc88(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *);
extern jboolean _jc_javax_xml_validation_TypeInfoProvider$method$isIdAttribute$fbee95af500f8e94(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);
extern jboolean _jc_javax_xml_validation_TypeInfoProvider$method$isSpecified$051f82ca54f2da8d(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$getAttributeTypeInfo$5fe17b3fb8096ff1;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$getElementTypeInfo$2ad99f5acfd4cc88;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$isIdAttribute$fbee95af500f8e94;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$isSpecified$051f82ca54f2da8d;

// Virtual methods structure
struct _jc_javax_xml_validation_TypeInfoProvider$vmethods {
	struct _jc_object	*(*getAttributeTypeInfo$5fe17b3fb8096ff1)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);
	struct _jc_object	*(*getElementTypeInfo$2ad99f5acfd4cc88)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *);
	jboolean	(*isIdAttribute$fbee95af500f8e94)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);
	jboolean	(*isSpecified$051f82ca54f2da8d)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint);
};

// Vtable
struct _jc_javax_xml_validation_TypeInfoProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_validation_TypeInfoProvider$vmethods	javax_xml_validation_TypeInfoProvider;
};

// Vtype
struct _jc_javax_xml_validation_TypeInfoProvider$vtype {
	_jc_type			type;
	_jc_javax_xml_validation_TypeInfoProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_validation_TypeInfoProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_validation_TypeInfoProvider$refs {
    _jc_javax_xml_validation_TypeInfoProvider$sub_refs	javax_xml_validation_TypeInfoProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_validation_TypeInfoProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs	javax_xml_validation_TypeInfoProvider;
};

// Object instance structure
struct _jc_javax_xml_validation_TypeInfoProvider$object {
	_jc_javax_xml_validation_TypeInfoProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_validation_TypeInfoProvider$vtype	*vtype;
	_jc_javax_xml_validation_TypeInfoProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_validation_TypeInfoProvider$vtype _jc_javax_xml_validation_TypeInfoProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_validation_TypeInfoProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_validation_TypeInfoProvider$class_object;

#endif	/* _JC_javax_xml_validation_TypeInfoProvider_H_ */

==> jc-1.4.6.tar.gz: javax/xml/validation/TypeInfoProvider.h <==
// public abstract class javax.xml.validation.TypeInfoProvider

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf22387b95bb0cb1 javax_xml_validation_TypeInfoProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_validation_TypeInfoProvider_H_
#define _JC_javax_xml_validation_TypeInfoProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_TypeInfo$object;

// Typedefs
typedef struct _jc_javax_xml_validation_TypeInfoProvider$sub_refs	_jc_javax_xml_validation_TypeInfoProvider$sub_refs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs	_jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$refs	_jc_javax_xml_validation_TypeInfoProvider$refs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$nonrefs	_jc_javax_xml_validation_TypeInfoProvider$nonrefs;
typedef struct _jc_javax_xml_validation_TypeInfoProvider$object	_jc_javax_xml_validation_TypeInfoProvider$object;

typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vmethods	_jc_javax_xml_validation_TypeInfoProvider$vmethods;
typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vtable	_jc_javax_xml_validation_TypeInfoProvider$vtable;
typedef const struct _jc_javax_xml_validation_TypeInfoProvider$vtype	_jc_javax_xml_validation_TypeInfoProvider$vtype;

// Constructors
extern void _jc_javax_xml_validation_TypeInfoProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_xml_validation_TypeInfoProvider$method$getAttributeTypeInfo$5fe17b3fb8096ff1(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_validation_TypeInfoProvider$method$getElementTypeInfo$2ad99f5acfd4cc88(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_xml_validation_TypeInfoProvider$method$isIdAttribute$fbee95af500f8e94(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_javax_xml_validation_TypeInfoProvider$method$isSpecified$051f82ca54f2da8d(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$getAttributeTypeInfo$5fe17b3fb8096ff1;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$getElementTypeInfo$2ad99f5acfd4cc88;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$isIdAttribute$fbee95af500f8e94;
extern _jc_method _jc_javax_xml_validation_TypeInfoProvider$method_info$isSpecified$051f82ca54f2da8d;

// Virtual methods structure
struct _jc_javax_xml_validation_TypeInfoProvider$vmethods {
	struct _jc_object	*(*getAttributeTypeInfo$5fe17b3fb8096ff1)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getElementTypeInfo$2ad99f5acfd4cc88)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *) _JC_JCNI_ATTR;
	jboolean	(*isIdAttribute$fbee95af500f8e94)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isSpecified$051f82ca54f2da8d)(_jc_env *, struct _jc_javax_xml_validation_TypeInfoProvider$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_validation_TypeInfoProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_validation_TypeInfoProvider$vmethods	javax_xml_validation_TypeInfoProvider;
};

// Vtype
struct _jc_javax_xml_validation_TypeInfoProvider$vtype {
	_jc_type			type;
	_jc_javax_xml_validation_TypeInfoProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_validation_TypeInfoProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_validation_TypeInfoProvider$refs {
    _jc_javax_xml_validation_TypeInfoProvider$sub_refs	javax_xml_validation_TypeInfoProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_validation_TypeInfoProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_validation_TypeInfoProvider$sub_nonrefs	javax_xml_validation_TypeInfoProvider;
};

// Object instance structure
struct _jc_javax_xml_validation_TypeInfoProvider$object {
	_jc_javax_xml_validation_TypeInfoProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_validation_TypeInfoProvider$vtype	*vtype;
	_jc_javax_xml_validation_TypeInfoProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_validation_TypeInfoProvider$vtype _jc_javax_xml_validation_TypeInfoProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_validation_TypeInfoProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_validation_TypeInfoProvider$class_object;

#endif	/* _JC_javax_xml_validation_TypeInfoProvider_H_ */
